@@ -1,6 +1,6 @@
 package Gapp::Button;
 {
-  $Gapp::Button::VERSION = '0.487';
+  $Gapp::Button::VERSION = '0.494';
 }
 
 use Moose;
@@ -35,6 +35,10 @@ sub BUILDARGS {
         $args{constructor} = 'new_with_label';
     }
     
+    for my $att ( qw( can_default has_default ) ) {
+        $args{properties}{$att} = delete $args{$att} if exists $args{$att};
+    }
+    
     __PACKAGE__->SUPER::BUILDARGS( %args );
 }
 
