@@ -1,6 +1,6 @@
 package Gapp::Object;
 {
-  $Gapp::Object::VERSION = '0.487';
+  $Gapp::Object::VERSION = '0.494';
 }
 
 use Moose;
@@ -24,11 +24,11 @@ has 'args' => (
 
 
 # signals to connect to
-has 'connected_signals' => (
+has 'signal_connect' => (
     is => 'ro',
     isa => 'ArrayRef',
     default => sub { [ ] },
-    init_arg => 'signal_connect',
+    reader => 'connected_signals',
 );
 
 
